#ifndef NEWEXERCISE_H
#define NEWEXERCISE_H

#include <QtGui>
#include "sql.h"

class NewExercise : public QDialog
{
    Q_OBJECT
public:
    explicit NewExercise(QWidget *parent = 0);
    void load(QString n);

private:
    SQL *sql;

    QLineEdit *txtName;
    QLineEdit *txtMuscle;
    QTextEdit *txtHowTo;
    QPushButton *btnSave;
    //QMaemo5ValueButtons
    QListView *btnGroup;
    QStandardItemModel *model;

    QString name;
private slots:
    void saveExercise();

signals:
    void closed();

};

#endif // NEWEXERCISE_H
